@@ -106,7 +106,10 @@ class ImageAnnotation(Image, ReviewItem):
     # reference image getter
     @property
     def reference_image(self):
-        return self._reference_image.path_to_image
+        if self._reference_image:
+            return self._reference_image.path_to_image
+        else:
+            return ""
 
     @reference_image.setter
     def reference_image(self, value):
