@@ -113,7 +113,7 @@ def _load_note_to_review(
         if a.attrib:
             # Rebuild images paths as absolute
             for k, v in a.attrib.items():
-                if k in {"path_to_image", "reference_image"}:
+                if v and k in {"path_to_image", "reference_image"}:
                     abs_path = folder_root.joinpath(v)
 
                     a.attrib[k] = str(abs_path)
